"
" fixed_join.vim: User-defined key mapping and optional command to keep cursor
" in place when joining lines in normal mode.
"
" Author: Tom Ryder <tom@sanctum.geek.nz>
" License: Same as Vim itself
"
if exists('g:loaded_fixed_join') || &compatible
  finish
endif
if v:version < 600
  finish
endif
let g:loaded_fixed_join = 1

" Declare function
function! s:FixedJoin()

  " Save current cursor position
  let l:lc = line('.')
  let l:cc = col('.')

  " Build and execute join command
  let l:command = '.,+' . v:count1 . 'join'
  execute l:command

  " Return the cursor to the saved position (Vim 6.0 fallback)
  if exists('*cursor')
    call cursor(l:cursor_line, l:cursor_col)
  else
    execute 'normal! '
          \ . l:cursor_line . 'G'
          \ . l:cursor_col . '|'
  endif

endfunction

" Create mapping proxy to the function just defined
noremap <silent> <unique>
      \ <Plug>FixedJoin
      \ :<C-U>call <SID>FixedJoin()<CR>

" If there's no mapping to it already, try to bind normal-mode J to it, to
" simply replace the old functionality
nmap <unique>
      \ J
      \ <Plug>FixedJoin

" Create a command as well in case it's useful
if has('user_commands')
  command -nargs=0
        \ FixedJoin
        \ call <SID>FixedJoin()
endif
